summaryrefslogtreecommitdiffstats
path: root/kig/kig/kig.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/kig/kig.h')
-rw-r--r--kig/kig/kig.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kig/kig/kig.h b/kig/kig/kig.h
index a042a2ba..ee65962c 100644
--- a/kig/kig/kig.h
+++ b/kig/kig/kig.h
@@ -103,14 +103,14 @@ class Kig : public KParts::MainWindow
* This method is called when it is time for the app to save its
* properties for session management purposes.
*/
- void saveProperties(KConfig *);
+ void saveProperties(TDEConfig *);
/**
* This method is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with \ref saveProperties
*/
- void readProperties(KConfig *);
+ void readProperties(TDEConfig *);
private slots:
void fileNew();
@@ -141,7 +141,7 @@ class Kig : public KParts::MainWindow
//#endif
KRecentFilesAction *m_recentFilesAction;
- KConfig* config;
+ TDEConfig* config;
static bool kimageioRegistered;
};
@@ -103,14 +103,14 @@ class Kig : public KParts::MainWindow
/**
- * This method is called when this app is restored. The KConfig
+ * This method is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with \ref saveProperties